==> open-xchange-documents-backend_7.6.2.orig.tar.bz2: open-xchange-documents-backend-7.6.2/com.openexchange.office.docx4j/src/main/java/org/docx4j/dml/CTBackgroundFillStyleList.java <==
/*
 *  Copyright 2007-2008, Plutext Pty Ltd.
 *
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.

    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

 */


package org.docx4j.dml;

import java.util.ArrayList;
import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;

import org.docx4j.wml.ContentAccessor;


/**
 * <p>Java class for CT_BackgroundFillStyleList complex type.
 *
 * <p>The following schema fragment specifies the expected content contained within this class.
 *
 * <pre>
 * &lt;complexType name="CT_BackgroundFillStyleList">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;group ref="{http://schemas.openxmlformats.org/drawingml/2006/main}EG_FillProperties" maxOccurs="unbounded" minOccurs="3"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 *
 *
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_BackgroundFillStyleList", propOrder = {
    "egFillProperties"
})
public class CTBackgroundFillStyleList implements ContentAccessor {

    @XmlElements({
        @XmlElement(name = "pattFill", type = CTPatternFillProperties.class),
        @XmlElement(name = "blipFill", type = CTBlipFillProperties.class),
        @XmlElement(name = "solidFill", type = CTSolidColorFillProperties.class),
        @XmlElement(name = "noFill", type = CTNoFillProperties.class),
        @XmlElement(name = "grpFill", type = CTGroupFillProperties.class),
        @XmlElement(name = "gradFill", type = CTGradientFillProperties.class)
    })
    protected List<Object> egFillProperties;

    /**
     * Gets the value of the egFillProperties property.
     *
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the egFillProperties property.
     *
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getEGFillProperties().add(newItem);
     * </pre>
     *
     *
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link CTPatternFillProperties }
     * {@link CTBlipFillProperties }
     * {@link CTSolidColorFillProperties }
     * {@link CTNoFillProperties }
     * {@link CTGroupFillProperties }
     * {@link CTGradientFillProperties }
     *
     *
     */
    public List<Object> getContent() {
        if (egFillProperties == null) {
            egFillProperties = new ArrayList<Object>();
        }
        return this.egFillProperties;
    }

}

==> open-xchange-documents-backend_7.10.6.orig.tar.bz2: open-xchange-documents-backend-7.10.6/com.openexchange.office.docx4j/src/main/java/org/docx4j/dml/CTBackgroundFillStyleList.java <==
/*
 *  Copyright 2007-2008, Plutext Pty Ltd.
 *
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.

    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

 */


package org.docx4j.dml;

import java.util.ArrayList;
import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;
import com.openexchange.office.filter.core.IContentAccessor;


/**
 * <p>Java class for CT_BackgroundFillStyleList complex type.
 *
 * <p>The following schema fragment specifies the expected content contained within this class.
 *
 * <pre>
 * &lt;complexType name="CT_BackgroundFillStyleList">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;group ref="{http://schemas.openxmlformats.org/drawingml/2006/main}EG_FillProperties" maxOccurs="unbounded" minOccurs="3"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 *
 *
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_BackgroundFillStyleList", propOrder = {
    "egFillProperties"
})
public class CTBackgroundFillStyleList implements IContentAccessor {

    @XmlElements({
        @XmlElement(name = "pattFill", type = CTPatternFillProperties.class),
        @XmlElement(name = "blipFill", type = CTBlipFillProperties.class),
        @XmlElement(name = "solidFill", type = CTSolidColorFillProperties.class),
        @XmlElement(name = "noFill", type = CTNoFillProperties.class),
        @XmlElement(name = "grpFill", type = CTGroupFillProperties.class),
        @XmlElement(name = "gradFill", type = CTGradientFillProperties.class)
    })
    protected List<Object> egFillProperties;

    /**
     * Gets the value of the egFillProperties property.
     *
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the egFillProperties property.
     *
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getEGFillProperties().add(newItem);
     * </pre>
     *
     *
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link CTPatternFillProperties }
     * {@link CTBlipFillProperties }
     * {@link CTSolidColorFillProperties }
     * {@link CTNoFillProperties }
     * {@link CTGroupFillProperties }
     * {@link CTGradientFillProperties }
     *
     *
     */
    public List<Object> getContent() {
        if (egFillProperties == null) {
            egFillProperties = new ArrayList<Object>();
        }
        return this.egFillProperties;
    }

}
